@@ -1,6 +1,5 @@
 // Copyright (C) 2019 The Qt Company Ltd.
 // SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
-// Qt-Security score:critical reason:cryptography
 
 #include "qopcuakeypair_p.h"
 #include "openssl_symbols_p.h"
@@ -28,7 +27,7 @@ QOpcUaKeyPairPrivate::~QOpcUaKeyPairPrivate()
 static int passwordCallback(char *passphraseBuffer, int maximumPassphraseSize, int writeOperation, void *userData) {
     QOpcUaKeyPair *source = reinterpret_cast<QOpcUaKeyPair*>(userData);
     QString passphrase;
-    source->passphraseNeeded(passphrase, maximumPassphraseSize, writeOperation == 1);
+    emit source->passphraseNeeded(passphrase, maximumPassphraseSize, writeOperation == 1);
 
     if (passphrase.isEmpty())
         return -1;
